Changelog
=================================================

v1.2.0
*    Add routines to plot values along semi axes
*    Add visual_report() for simple beam analysis
*    Fix error when calculating circular radius
*    Add missing scipy requirement
*    Improve README.rst with figure

v1.1.0
------
*    Works dramatically better across a wide range of images
*    Minor API changes to `beam_size()`
*    Use ISO 11146 integration areas
*    Add background routines for corners
*    Add functions for rotations
*    Eliminate old threshold technique
*    Use google docstyle for functions
*    Explain background and integration areas in notebooks
*    Tweak notebooks for clarity

v1.0.2
------
*    use sphinx for documentation
*    revise Jupyter notebooks

v1.0.1
------
*    trivial fix for release.txt
*    improve text
*    remove completed tasks
*    initial commit of 07-M2-Measurement.ipynb
*    bump version

v1.0.0
------
*    first pass at docs
*    General doc improvements
*    add routine to draw default figure
*    handle symmetric case dx=dy better
*    add new definitions and test dx=dy case

v0.2.0
------
*    initial commit
*    ensure float used for sums
*    first public release
